@@ -34,7 +34,7 @@ function set_build_root {
     BUILD_ROOT="${DIR}/_build_root"
     REPO_CLONE="${BUILD_ROOT}/${MINGW}"/gajim
     MINGW_ROOT="${BUILD_ROOT}/${MINGW}"
-    PACKAGE_DIR="${BUILD_ROOT}/${MINGW}/lib/python3.6/site-packages"
+    PACKAGE_DIR="${BUILD_ROOT}/${MINGW}/lib/python3.7/site-packages"
 }
 
 function build_pacman {
@@ -70,10 +70,14 @@ function create_root {
 }
 
 function install_deps {
+    # Downgrade GLIB, resolver is broken on Windows 7
+    curl -o "${BUILD_ROOT}"/mingw-w64-x86_64-glib2-2.56.2-1-any.pkg.tar.xz \
+        https://gajim.org/downloads/snap/win/build/mingw-w64-x86_64-glib2-2.56.2-1-any.pkg.tar.xz
+    build_pacman --noconfirm -U "${BUILD_ROOT}"/mingw-w64-x86_64-glib2-2.56.2-1-any.pkg.tar.xz
+
     build_pacman --noconfirm -S mingw-w64-"${ARCH}"-gtk3 mingw-w64-"${ARCH}"-"${PYTHON_ID}" \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-gobject \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-pip \
-        mingw-w64-"${ARCH}"-gstreamer \
         mingw-w64-"${ARCH}"-adwaita-icon-theme \
         mingw-w64-"${ARCH}"-libwebp \
         mingw-w64-"${ARCH}"-sqlite3 \
@@ -90,14 +94,15 @@ function install_deps {
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-six
 
     PIP_REQUIREMENTS="\
-pyasn1
 git+https://dev.gajim.org/gajim/python-nbxmpp.git
-git+https://github.com/dlitz/pycrypto.git
 git+https://dev.gajim.org/lovetox/pybonjour-python3.git
+git+https://github.com/enthought/pywin32-ctypes.git
 keyring
 python-gnupg
 python-axolotl
 qrcode
+cssutils
+precis-i18n
 "
 
     build_pip install $(echo "$PIP_REQUIREMENTS" | tr ["\\n"] [" "])
@@ -134,7 +139,7 @@ function install_gajim {
         "${QL_VERSION}" "${MINGW_ROOT}"/bin
 
     # Install plugin installer
-    curl -o "${BUILD_ROOT}"/plugin_installer.zip https://ftp.gajim.org/plugins_1/plugin_installer.zip
+    curl -o "${BUILD_ROOT}"/plugin_installer.zip https://ftp.gajim.org/plugins_1.1_zip/plugin_installer.zip
     mkdir "${PACKAGE_DIR}"/gajim/data/plugins
     7z x -o"${PACKAGE_DIR}"/gajim/data/plugins "${BUILD_ROOT}"/plugin_installer.zip
 
@@ -164,7 +169,6 @@ function cleanup_install {
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-pip mingw-w64-"${ARCH}"-ncurses || true
     build_pacman --noconfirm -Rdd mingw-w64-"${ARCH}"-tk || true
     build_pacman --noconfirm -Rdd mingw-w64-"${ARCH}"-tcl || true
-    build_pacman --noconfirm -Rdd mingw-w64-"${ARCH}"-gsl || true
 
     #delete translations we don't support
     for d in "${MINGW_ROOT}"/share/locale/*/LC_MESSAGES; do
@@ -294,12 +298,17 @@ function cleanup_install {
 
 }
 
+function download_ssl_libs {
+    # Python needs these ssl libs but msys does not provide them
+    curl -o "${BUILD_ROOT}"/ssl.zip https://gajim.org/downloads/snap/win/build/ssl.zip
+    7z x -o"${MINGW_ROOT}"/bin "${BUILD_ROOT}"/ssl.zip
+}
+
 function move_ssl_libs {
     # Pythons ssl module searches in that path for these dlls, if they are not there
     # C:/Windows/system32 is searcherd and potentially wrong versioned dlls are found there
-    cp "${MINGW_ROOT}"/bin/libeay32.dll "${MINGW_ROOT}"/lib/python3.6/lib-dynload/libeay32.dll
-    cp "${MINGW_ROOT}"/bin/ssleay32.dll "${MINGW_ROOT}"/lib/python3.6/lib-dynload/ssleay32.dll
-
+    cp "${MINGW_ROOT}"/bin/libeay32.dll "${MINGW_ROOT}"/lib/python3.7/lib-dynload/libeay32.dll
+    cp "${MINGW_ROOT}"/bin/ssleay32.dll "${MINGW_ROOT}"/lib/python3.7/lib-dynload/ssleay32.dll
 }
 
 function build_installer {
